# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'gravtools/gui/dialog_setup_data.ui'
#
# Created by: PyQt5 UI code generator 5.15.6
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog_setup_data(object):
    def setupUi(self, Dialog_setup_data):
        Dialog_setup_data.setObjectName("Dialog_setup_data")
        Dialog_setup_data.resize(512, 122)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(Dialog_setup_data)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.checkBox_drift_ref_epoch_active_obs_only = QtWidgets.QCheckBox(Dialog_setup_data)
        self.checkBox_drift_ref_epoch_active_obs_only.setObjectName("checkBox_drift_ref_epoch_active_obs_only")
        self.verticalLayout_3.addWidget(self.checkBox_drift_ref_epoch_active_obs_only)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem)

        self.retranslateUi(Dialog_setup_data)
        QtCore.QMetaObject.connectSlotsByName(Dialog_setup_data)

    def retranslateUi(self, Dialog_setup_data):
        _translate = QtCore.QCoreApplication.translate
        Dialog_setup_data.setWindowTitle(_translate("Dialog_setup_data", "Setup data options"))
        self.checkBox_drift_ref_epoch_active_obs_only.setToolTip(_translate("Dialog_setup_data", "Consider only active observations in the determination of the drift polynomial reference epoch(s)."))
        self.checkBox_drift_ref_epoch_active_obs_only.setText(_translate("Dialog_setup_data", "Consider only active observations for the reference epoch"))
